Asciiquarium Redux (Web)

## Settings

### Basics

FPS
Speed
Density
Color
Seed
Treasure chest
Castle
Fish turning
AI behavior
Auto font (fit castle)
Font min size (px)
Font max size (px)
Fish
Direction bias
Speed min
Speed max
Fish scale
Seaweed
Seaweed scale
Sway min
Sway max
Scene
Waterline top (row)
Chest burst (s)
Fish tank mode
Fish tank margin (cols)
Spawn
Start delay min (s)
Start delay max (s)
Interval min (s)
Interval max (s)
Max concurrent specials
Global cooldown (s)
Special Weights
Set to 0 to disable
Shark
Fishhook
Whale
Ship
Ducks
Dolphins
Swan
Monster
Big Fish
Fishhook
Hook dwell (s)

## About

Loading README…
Open README on GitHub